@@ -169,7 +169,7 @@ class ANALITZA_EXPORT Expression
         /**
          *    Converts the expression to a string expression.
          */
-        QString toString() const;
+        Q_SCRIPTABLE QString toString() const;
         
         /**
          *    Converts the expression to MathML.
@@ -267,6 +267,7 @@ class ANALITZA_EXPORT Expression
         static Expression constructString(const QString& str);
         
         /** @returns if a non-mathml expression is fully introduced (e.g. has closed all parentheses).
+            @param exp the expression to analyze
             @param justempty tells if it's an expression with just spaces and comments
          */
         static bool isCompleteExpression(const QString& exp, bool justempty=false);
@@ -278,4 +279,6 @@ class ANALITZA_EXPORT Expression
 
 }
 
+Q_DECLARE_METATYPE(Analitza::Expression)
+
 #endif
